==> wire-runtime-3.4.0-javadoc.jar: wire-schema/com.squareup.wire.schema.internal.parser/-enum-element/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema.internal.parser](../index.md) / [EnumElement](./index.md)

# EnumElement

`data class EnumElement : `[`TypeElement`](../-type-element/index.md)

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `EnumElement(location: `[`Location`](../../com.squareup.wire.schema/-location/index.md)`, name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "", options: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`OptionElement`](../-option-element/index.md)`> = emptyList(), constants: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EnumConstantElement`](../-enum-constant-element/index.md)`> = emptyList())` |

### Properties

| Name | Summary |
|---|---|
| [constants](constants.md) | `val constants: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EnumConstantElement`](../-enum-constant-element/index.md)`>` |
| [documentation](documentation.md) | `val documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [location](location.md) | `val location: `[`Location`](../../com.squareup.wire.schema/-location/index.md) |
| [name](name.md) | `val name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [nestedTypes](nested-types.md) | `val nestedTypes: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`TypeElement`](../-type-element/index.md)`>` |
| [options](options.md) | `val options: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`OptionElement`](../-option-element/index.md)`>` |

### Functions

| Name | Summary |
|---|---|
| [toSchema](to-schema.md) | `fun toSchema(syntaxRules: `[`SyntaxRules`](../../com.squareup.wire.schema/-syntax-rules/index.md)`): <ERROR CLASS>` |

==> wire-runtime-3.7.1-javadoc.jar: wire-schema/com.squareup.wire.schema.internal.parser/-enum-element/index.md <==
[wire-schema](../../index.md) / [com.squareup.wire.schema.internal.parser](../index.md) / [EnumElement](./index.md)

# EnumElement

`data class EnumElement : `[`TypeElement`](../-type-element/index.md)

### Constructors

| Name | Summary |
|---|---|
| [&lt;init&gt;](-init-.md) | `EnumElement(location: `[`Location`](../../com.squareup.wire.schema/-location/index.md)`, name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)`, documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html)` = "", options: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`OptionElement`](../-option-element/index.md)`> = emptyList(), constants: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EnumConstantElement`](../-enum-constant-element/index.md)`> = emptyList())` |

### Properties

| Name | Summary |
|---|---|
| [constants](constants.md) | `val constants: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`EnumConstantElement`](../-enum-constant-element/index.md)`>` |
| [documentation](documentation.md) | `val documentation: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [location](location.md) | `val location: `[`Location`](../../com.squareup.wire.schema/-location/index.md) |
| [name](name.md) | `val name: `[`String`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin/-string/index.html) |
| [nestedTypes](nested-types.md) | `val nestedTypes: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`TypeElement`](../-type-element/index.md)`>` |
| [options](options.md) | `val options: `[`List`](https://kotlinlang.org/api/latest/jvm/stdlib/kotlin.collections/-list/index.html)`<`[`OptionElement`](../-option-element/index.md)`>` |

### Functions

| Name | Summary |
|---|---|
| [toSchema](to-schema.md) | `fun toSchema(): <ERROR CLASS>` |
